@@ -2,12 +2,17 @@ context("dependencies")
 
 v3 <- d3_dep_v3()
 v3_offline <- d3_dep_v3(offline=FALSE)
+
 v4 <- d3_dep_v4()
 v4_offline <- d3_dep_v4(offline=FALSE)
 
+jetpack <- d3_dep_jetpack()
+jetpack_offline <- d3_dep_jetpack(offline=FALSE)
+
 test_that("d3_dep-* returns html_dependency", {
   expect_is(v3, "html_dependency")
   expect_is(v4, "html_dependency")
+  expect_is(jetpack, 'html_dependency')
 })
 
 test_that("d3_dep-* src href is a valid url", {
@@ -17,14 +22,15 @@ test_that("d3_dep-* src href is a valid url", {
   }
   expect_true(is_valid_url(file.path(v3_offline$src$href,v3$script)))
   expect_true(is_valid_url(file.path(v4_offline$src$href,v4$script)))
+  expect_true(is_valid_url(file.path(jetpack_offline$src$href,jetpack$script)))
 })
 
 test_that("d3_dep-* src file is a valid file", {
   expect_true(file.exists(file.path(v3$src$file,v3$script)))
   expect_true(file.exists(file.path(v4$src$file,v4$script)))
+  expect_true(file.exists(file.path(jetpack$src$file, jetpack$script)))
 })
 
-
 test_that("d3_dep_v4 on latest d3 release", {
   skip_if_not_installed("github")
 
@@ -34,4 +40,14 @@ test_that("d3_dep_v4 on latest d3 release", {
   )
 })
 
+test_that("d3-jetpack on latest release", {
+  skip_on_cran()
+  skip_on_travis()
 
+  expect_identical(
+    jetpack$version,
+    jsonlite::fromJSON(
+      "https://unpkg.com/d3-jetpack/package.json"
+    )$version
+  )
+})
